@@ -994,7 +994,11 @@ static int pulse_hw_constraint(snd_pcm_pulse_t * pcm)
 		SND_PCM_FORMAT_FLOAT_LE,
 		SND_PCM_FORMAT_FLOAT_BE,
 		SND_PCM_FORMAT_S32_LE,
-		SND_PCM_FORMAT_S32_BE
+		SND_PCM_FORMAT_S32_BE,
+		SND_PCM_FORMAT_S24_3LE,
+		SND_PCM_FORMAT_S24_3BE,
+		SND_PCM_FORMAT_S24_LE,
+		SND_PCM_FORMAT_S24_BE
 	};
 
 	int err;
@@ -1139,7 +1143,7 @@ SND_PCM_PLUGIN_DEFINE_FUNC(pulse)
 	err = pulse_hw_constraint(pcm);
 	if (err < 0) {
 		snd_pcm_ioplug_delete(&pcm->io);
-		goto error;
+		goto error2;
 	}
 
 	*pcmp = pcm->io.pcm;
@@ -1152,6 +1156,7 @@ error:
 	free(pcm->device);
 	free(pcm);
 
+error2:
 	if (fallback_name)
 		return snd_pcm_open_fallback(pcmp, root, fallback_name, name,
 					     stream, mode);
